/* SPDX-License-Identifier: (GPL-2.0 OR MIT) */
/*
 *  Copyright 2022 NXP
 */

#ifndef __DT_BINDINGS_IMX93_POWER_H__
#define __DT_BINDINGS_IMX93_POWER_H__

#define IMX93_MEDIABLK_PD_MIPI_DSI		0
#define IMX93_MEDIABLK_PD_MIPI_CSI		1
#define IMX93_MEDIABLK_PD_PXP			2
#define IMX93_MEDIABLK_PD_LCDIF			3
#define IMX93_MEDIABLK_PD_ISI			4
#define IMX93_MEDIABLK_PD_MIPI_PHY		5

#endif
