/* SPDX-License-Identifier: GPL-2.0 */
#ifndef __DT_BINDINGS_POWER_RK3036_POWER_H__
#define __DT_BINDINGS_POWER_RK3036_POWER_H__

#define RK3036_PD_MSCH		0
#define RK3036_PD_CORE		1
#define RK3036_PD_PERI		2
#define RK3036_PD_VIO		3
#define RK3036_PD_VPU		4
#define RK3036_PD_GPU		5
#define RK3036_PD_SYS		6

#endif
