/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause) */
/*
 * This header provides constants for binding nvidia,tegra114-soctherm.
 */

#ifndef _DT_BINDINGS_THERMAL_TEGRA114_SOCTHERM_H
#define _DT_BINDINGS_THERMAL_TEGRA114_SOCTHERM_H

#define TEGRA114_SOCTHERM_SENSOR_CPU 0
#define TEGRA114_SOCTHERM_SENSOR_MEM 1
#define TEGRA114_SOCTHERM_SENSOR_GPU 2
#define TEGRA114_SOCTHERM_SENSOR_PLLX 3

#define TEGRA114_SOCTHERM_THROT_LEVEL_NONE 0
#define TEGRA114_SOCTHERM_THROT_LEVEL_LOW  1
#define TEGRA114_SOCTHERM_THROT_LEVEL_MED  2
#define TEGRA114_SOCTHERM_THROT_LEVEL_HIGH 3

#endif
