/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause)
 *
 * Copyright (C) 2024 Renesas Electronics Corp.
 */
#ifndef __DT_BINDINGS_CLOCK_RENESAS_R9A08G045_VBATTB_H__
#define __DT_BINDINGS_CLOCK_RENESAS_R9A08G045_VBATTB_H__

#define VBATTB_XC		0
#define VBATTB_XBYP		1
#define VBATTB_MUX		2
#define VBATTB_VBATTCLK		3

#endif /* __DT_BINDINGS_CLOCK_RENESAS_R9A08G045_VBATTB_H__ */
