/* SPDX-License-Identifier: GPL-2.0 */

#ifndef __LINUX_GPIO_DEFS_H
#define __LINUX_GPIO_DEFS_H

#define GPIO_LINE_DIRECTION_IN		1
#define GPIO_LINE_DIRECTION_OUT		0

#endif /* __LINUX_GPIO_DEFS_H */
