/* SPDX-License-Identifier: (GPL-2.0-only OR MIT) */
/*
 * Copyright (C) 2024 Amlogic, Inc. All rights reserved
 */
#ifndef _DT_BINDINGS_AMLOGIC_A4_POWER_H
#define _DT_BINDINGS_AMLOGIC_A4_POWER_H

#define PWRC_A4_AUDIO_ID				0
#define PWRC_A4_SDIOA_ID				1
#define PWRC_A4_EMMC_ID					2
#define PWRC_A4_USB_COMB_ID				3
#define PWRC_A4_ETH_ID					4
#define PWRC_A4_VOUT_ID					5
#define PWRC_A4_AUDIO_PDM_ID				6
#define PWRC_A4_DMC_ID					7
#define PWRC_A4_SYS_WRAP_ID				8
#define PWRC_A4_AO_I2C_S_ID				9
#define PWRC_A4_AO_UART_ID				10
#define PWRC_A4_AO_IR_ID				11

#endif
