/* SPDX-License-Identifier: GPL-2.0 */
/*
 * This header provides constants for TI SERDES.
 */

#ifndef _DT_BINDINGS_TI_SERDES
#define _DT_BINDINGS_TI_SERDES

/* Clock index for output clocks from WIZ */

/* MUX Clocks */
#define TI_WIZ_PLL0_REFCLK	0
#define TI_WIZ_PLL1_REFCLK	1
#define TI_WIZ_REFCLK_DIG	2

/* Reserve index here for future additions */

/* MISC Clocks */
#define TI_WIZ_PHY_EN_REFCLK	16

#endif /* _DT_BINDINGS_TI_SERDES */
