/* SPDX-License-Identifier: (GPL-2.0+ OR MIT) */
/*
 * Copyright (C) 2021 Samuel Holland <samuel@sholland.org>
 */

#ifndef _DT_BINDINGS_RST_SUN20I_D1_R_CCU_H_
#define _DT_BINDINGS_RST_SUN20I_D1_R_CCU_H_

#define RST_BUS_R_TIMER		0
#define RST_BUS_R_TWD		1
#define RST_BUS_R_PPU		2
#define RST_BUS_R_IR_RX		3
#define RST_BUS_R_RTC		4
#define RST_BUS_R_CPUCFG	5

#endif /* _DT_BINDINGS_RST_SUN20I_D1_R_CCU_H_ */
