/* SPDX-License-Identifier: GPL-2.0-only OR BSD-2-Clause */
/*
 * Marvell PXA1908 power domains
 *
 * Copyright 2025, Duje Mihanović <duje@dujemihanovic.xyz>
 */

#ifndef __DTS_MARVELL_PXA1908_POWER_H
#define __DTS_MARVELL_PXA1908_POWER_H

#define PXA1908_POWER_DOMAIN_VPU	0
#define PXA1908_POWER_DOMAIN_GPU	1
#define PXA1908_POWER_DOMAIN_GPU2D	2
#define PXA1908_POWER_DOMAIN_DSI	3
#define PXA1908_POWER_DOMAIN_ISP	4
#define PXA1908_POWER_DOMAIN_AUDIO	5

#endif
