/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (C) 2018 The Linux Foundation. All rights reserved.
 */

#ifndef _DT_BINDINGS_RESET_PDC_SDM_845_H
#define _DT_BINDINGS_RESET_PDC_SDM_845_H

#define PDC_APPS_SYNC_RESET	0
#define PDC_SP_SYNC_RESET	1
#define PDC_AUDIO_SYNC_RESET	2
#define PDC_SENSORS_SYNC_RESET	3
#define PDC_AOP_SYNC_RESET	4
#define PDC_DEBUG_SYNC_RESET	5
#define PDC_GPU_SYNC_RESET	6
#define PDC_DISPLAY_SYNC_RESET	7
#define PDC_COMPUTE_SYNC_RESET	8
#define PDC_MODEM_SYNC_RESET	9
#define PDC_WLAN_RF_SYNC_RESET	10
#define PDC_WPSS_SYNC_RESET	11

#endif
